@@ -21,17 +21,9 @@ except:
     from src import collections as collections
 #import re
 import ast
+from custom_exceptions import *
 
 
-class GenotypeNetworkInitError(Exception):
-    """error raised when something went wrong with Network initialization,
-    such as an improper genotype string or a wrong parameter"""
-    pass
-class GenotypeNetworkAttributeError(Exception):
-    """error raised when something tried to access to an attribute
-    of the genotype network that doesn't exists"""
-    pass
-
 class GenotypeNetwork(igraph.Graph):
     """
     Represents a Genotype Network
